==> hopit_0.9.0.tar.gz: hopit/R/msgtxt.R <==
#' @noRd
#' @keywords internal
hopit_msg <- function(x)
  switch(x,
         '1'  = 'Missing "$parcount" in model object.',
         '2'  = 'Missing model coefficients.',
         '3'  = 'Wrong number of parameters.',
         '4'  = 'Lambda must be given.',
         '5'  = 'Improving fit using the nlm() method...',
         '6'  = 'Optimization error. Probably bad starting parameters or the model is unidentifiable.',
         '7'  = 'Something is wrong with the survey package.',
         '8'  = 'Please specify the method of fit',
         '9'  = 'Unknown fit method.',
         '10' = 'Calculating the starting parameters...',
         '11' = 'Fitting the model...',
         '12' = 'Calculating the maximum latent range...',
         '13' = ' done\n',
         '14' = 'Calculating the Hessian matrix...',
         '15' = 'Calculating the LL gradient (estfun)...',
         '16' = 'Including survey design...',
         '17' = 'Unknown link function:',
         '18' = '\nThreshold variable(s) detected in reg.formula. Model may be not identifiable.\n', #start.vglm
         '19' = 'Starting set of parameters cannot be found using the glm method.', #start.glm
         '20' = 'Wrong start method.', #get.hopit.start  UNUSED
         '21' = 'Threshold-health variables must be factors.', #get.hopit.start
         '22' = 'boot must be of class "hopit.boot".', #boot
         '23' = 'No vcov detected.', #boot
         '24' = 'Are the levels', #checks
         '25' = 'sorted in increasing order?', #checks
         '26' = 'if not please set decreasing.levels to TRUE.', #checks
         '27' = '"decreasing.levels" must be given.', #checks
         '28' = 'Unknown method.', #checks
         '29' = 'The threshold formula should be given without the dependent variable.', #checks
         '30' = 'The strata formula should be given without the dependent variable.', #checks
         '31' = 'Offset is not supported.', #checks
         '32' = 'Model is probably unidentifiable, $vcov (variance-covariance matrix) cannot be computed.', #checks
         '33' = 'Response must be a factor with ordered levels.', #checks
         '34' = 'Response must have 3 or more levels.', #checks
         '35' = 'Multiple weights specification detected. Please use either the design or the weights parameter.', #checks
         '36' = 'Vector of the survey weights must be of the same length as the data.', #checks
         '37' = 'Cannot compute variance-covariance matrix:\n', #generics
         '38' = 'Hessian cannot be calculated.', #generics
         '39' = '"robust.vcov" parameter ignored, survey design was detected.', #generics
         '40' = 'Variance-covariance matrix:\n', #generics
         '41' = '\nVariance-covariance matrix adjusted for the survey design.\n', #generics
         '42' = '\nVariance-covariance matrix based on a sandwich estimator.\n', #generics
         '43' = 'Negative variances were detected; try different robust.se/survey options and check the fit!', #generics
         '44' = 'Survey weights were detected. Standard errors were adjusted for the survey design.\n', #generics
         '45' = 'Problem with some standard errors; please try the option "robust.se" == TRUE.', #generics
         '46' = 'Something wrong.', #generics
         '47' = 'AIC for models with a survey design is not yet implemented.', #generics
         '48' = 'At least two objects must be listed.', #generics
         '49' = 'Anova (LRTs):\nMethod: "', #generics
         '50' = 'Unknown direction.', #generics
         '51' = 'Models have different survey designs.', #generics
         '52' = 'The "full" model must have more parameters than the "nested" one.', #generics
         '53' = 'Negligible difference between log likelihoods.', #generics
         '54' = 'The "nested" model has a higher likelihood than the "full" model. Try to improve the fit of the models.', #generics
         '55' = 'A sigma parameter is present in the nested model, but is absent in the full model.', #generics
         '56' = 'Probably non nested latent formulas (check reg.formula)).', #generics
         '57' = 'Probably non nested threshold formulas (check thresh.formula)).', #generics
         '58' = 'LRT for models with a survey design is not yet implemented.', #generics
         '59' = '\nLikelihood ratio test:\n', #generics
         '60' = 'Log likelihood maximum not reached.', #generics
         '61' = 'Problem in:', #generics
         '62' = 'All parameters seem to be at arg.max (at the optimum).\n', #generics
         '63' = 'Scale factors', #generics
         '64' = 'Full model:\n', #generics
         '65' = "Formula (latent variables):", #generics
         '66' = "Formula (threshold variables):", #generics
         '67' = '\nNested model:\n', #generics
         '68' = 'Latent formulas are not nested.', #generics
         '69' = 'Threshold formulas are not nested.', #generics
         '70' = "Sigma:", #generics
         '71' = '\nRobust SE were used (sandwich estimator of variance-covariance matrix).\n', #generics
         '72' = 'Link:', #generics
         '73' = 'Number of cases:', #generics
         '74' = 'Response levels:', #generics
         '75' = 'Log-likelihood:', #generics
         '76' = 'Deviance:', #generics
         '77' = 'Sigma parameter:', #generics
         '78' = '\nCoefficients of the latent variable:\n', #generics
         '79' = '\nThreshold coefficients (Lambda):\n', #generics
         '80' = '\nThreshold coefficients (Gamma):\n', #generics
         '81' = '\nFixed Sigma:\n', #generics
         '82' = '\nSigma:\n', #generics
         '83' = 'Unknown response.', #reporting styles
         '84' = 'Unknown group.labels.type.', #reporting styles
         '85' = 'Some cut-points are NA or duplicated.', #reporting styles
         '86' = '"formula" must be of the class formula.', #reporting styles
         '87' = '',
         '88' = '',
         '89' = 'The PPS design is not supported yet.',
         '90' = '',
         '91' = 'The same terms are found in the latent and the threshold model:',
         '92' = 'The model cannot use the same variables (or their interactions) to model thresholds and the latent measure. Also, avoid using "*" to model the latent-threshold interactions.',
         '93' = 'No main effects are found for the',
         '94' = 'interaction.',
         '95' = '"use_weights" must be given.',
         '96' = 'Wrong number of starting parameters.',
         '97' = 'I(...) not yet implemented.',
         '98' = 'Cannot find the starting parameters. Please consider scaling, transforming, or re-coding as a factor one or more of the numerical (continuous) variables used in the model. The very basic transformations can be done using a control parameter (see example 5 in the hopit() function).',
         '99' = 'Unknown transformation type.',
         '100' = 'No latent variables detected in the latent formula.',
         '101' = 'No response detected in the latent formula.',
         '102' = 'Response found as a predictor in the latent or the threshold formulas.', #>>>>??????>>>>>
         '103' = 'Should not happen.',
         '104' = 'Unused levels dropped from '
  )

==> hopit_0.10.2.tar.gz: hopit/R/msgtxt.R <==
#' @noRd
#' @keywords internal
hopit_msg <- function(x)
  switch(x,
         '1'  = 'Missing "$parcount" in model object.',
         '2'  = 'Missing model coefficients.',
         '3'  = 'Wrong number of parameters.',
         '4'  = 'Lambda must be given.',
         '5'  = 'Improving fit using the nlm() method...',
         '6'  = 'Optimization error. Probably bad starting parameters or the model is unidentifiable.',
         '7'  = 'Something is wrong with the survey package.',
         '8'  = 'Please specify the method of fit',
         '9'  = 'Unknown fit method.',
         '10' = 'Calculating the starting parameters...',
         '11' = 'Fitting the model...',
         '12' = 'Calculating the maximum latent range...',
         '13' = ' done\n',
         '14' = 'Calculating the Hessian matrix...',
         '15' = 'Calculating the LL gradient (estfun)...',
         '16' = 'Including survey design...',
         '17' = 'Unknown link function:',
         '18' = '\nThreshold variable(s) detected in reg.formula. Model may be not identifiable.\n', #start.vglm
         '19' = 'Starting set of parameters cannot be found using the glm method.', #start.glm
         '20' = 'Wrong start method.', #get.hopit.start  UNUSED
         '21' = 'Threshold-health variables must be factors.', #get.hopit.start
         '22' = 'boot must be of class "hopit.boot".', #boot
         '23' = 'No vcov detected.', #boot
         '24' = 'Are the levels', #checks
         '25' = 'sorted in increasing order?', #checks
         '26' = 'if not please set decreasing.levels to TRUE.', #checks
         '27' = '"decreasing.levels" must be given.', #checks
         '28' = 'Unknown method.', #checks
         '29' = 'The threshold formula should be given without the dependent variable.', #checks
         '30' = 'The strata formula should be given without the dependent variable.', #checks
         '31' = 'Offset is not supported.', #checks
         '32' = 'Model is probably unidentifiable, $vcov (the variance-covariance matrix) cannot be computed.', #checks
         '33' = 'Response must be a factor with ordered levels.', #checks
         '34' = 'Response must have 3 or more levels.', #checks
         '35' = 'Multiple weights specification detected. Please use either the design or the weights parameter.', #checks
         '36' = 'Vector of the survey weights must be of the same length as the data.', #checks
         '37' = 'Cannot compute the variance-covariance matrix:\n', #generics
         '38' = 'Hessian cannot be calculated.', #generics
         '39' = '"robust.vcov" parameter ignored, survey design was detected.', #generics
         '40' = 'The variance-covariance matrix:\n', #generics
         '41' = '\nThe variance-covariance matrix adjusted for the survey design.\n', #generics
         '42' = '\nThe variance-covariance matrix based on a sandwich estimator.\n', #generics
         '43' = 'Negative variances were detected; try different robust.se/survey options and check the fit!', #generics
         '44' = 'Survey weights were detected. Standard errors were adjusted for the survey design.\n', #generics
         '45' = 'Problem with some standard errors; please try the option "robust.se" == TRUE.', #generics
         '46' = 'Something wrong.', #generics
         '47' = 'AIC for models with a survey design is not yet implemented.', #generics
         '48' = 'At least two objects must be listed.', #generics
         '49' = 'Anova (LRTs):\nMethod: "', #generics
         '50' = 'Unknown direction.', #generics
         '51' = 'Models have different survey designs.', #generics
         '52' = 'The "full" model must have more parameters than the "nested" one.', #generics
         '53' = 'Negligible difference between log likelihoods.', #generics
         '54' = 'The "nested" model has a higher likelihood than the "full" model. Try to improve the fit of the models.', #generics
         '55' = 'A sigma parameter is present in the nested model, but is absent in the full model.', #generics
         '56' = 'Probably non nested latent formulas (check reg.formula)).', #generics
         '57' = 'Probably non nested threshold formulas (check thresh.formula)).', #generics
         '58' = 'LRT for models with a survey design is not yet implemented.', #generics
         '59' = 'Likelihood ratio test:\n', #generics
         '60' = 'Log likelihood maximum not reached.', #generics
         '61' = 'Problem in:', #generics
         '62' = 'All parameters seem to be at arg.max (at the optimum).\n', #generics
         '63' = 'Scale factors', #generics
         '64' = 'Full model:\n', #generics
         '65' = "Formula (latent variables):", #generics
         '66' = "Formula (threshold variables):", #generics
         '67' = '\nNested model:\n', #generics
         '68' = 'Latent formulas are not nested.', #generics
         '69' = 'Threshold formulas are not nested.', #generics
         '70' = "Sigma:", #generics
         '71' = '\nRobust SE were used (sandwich estimator of the variance-covariance matrix).\n', #generics
         '72' = 'Link:', #generics
         '73' = 'Number of cases:', #generics
         '74' = 'Response levels:', #generics
         '75' = 'Log-likelihood:', #generics
         '76' = 'Deviance:', #generics
         '77' = 'Sigma parameter:', #generics
         '78' = '\nCoefficients of the latent variable:\n', #generics
         '79' = '\nThreshold coefficients (Lambda):\n', #generics
         '80' = '\nThreshold coefficients (Gamma):\n', #generics
         '81' = '\nFixed Sigma:\n', #generics
         '82' = '\nSigma:\n', #generics
         '83' = 'Unknown response.', #reporting styles
         '84' = 'Unknown group.labels.type.', #reporting styles
         '85' = 'Some cut-points are NA or duplicated.', #reporting styles
         '86' = '"formula" must be of the class formula.', #reporting styles
         '87' = '',
         '88' = '',
         '89' = 'The PPS design is not supported yet.',
         '90' = '',
         '91' = 'The same terms are found in the latent and the threshold model:',
         '92' = 'The model cannot use the same variables (or their interactions) to model thresholds and the latent measure. Also, avoid using "*" to model the latent-threshold interactions.',
         '93' = 'No main effects are found for the',
         '94' = 'interaction.',
         '95' = '"use_weights" must be given.',
         '96' = 'Wrong number of starting parameters.',
         '97' = 'I(...) not yet implemented.',
         '98' = 'Cannot find the starting parameters. Please consider scaling, transforming, or re-coding as a factor one or more of the numerical (continuous) variables used in the model. The very basic transformations can be done using a control parameter (see example 5 in the hopit() function).',
         '99' = 'Unknown transformation type.',
         '100' = 'No latent variables detected in the latent formula.',
         '101' = 'No response detected in the latent formula.',
         '102' = 'Response found as a predictor in the latent or the threshold formulas.', #>>>>??????>>>>>
         '103' = 'Should not happen.',
         '104' = 'Unused levels dropped from '
  )
